@@ -17,6 +17,7 @@
 #include "htp-files.h"
 #include "def-proc.h"
 #include "file-proc.h"
+#include "snprintf.h"
 
 #ifdef HAVE_PIPE
 #include <errno.h>
@@ -619,7 +620,7 @@ uint OutputProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext)
     FreeMemory(attrib);
 
     result = ReadBlockToFile(task, expand, htmlMarkup->tag, &outputfile);
-    FreeMemory(outputfile.name);
+    FreeMemory((char *) outputfile.name);
     CloseStream(&outputfile);
 
     return result == FALSE ? MARKUP_ERROR : DISCARD_MARKUP;
