@@ -15,6 +15,7 @@
 #include "option.h"
 #include "streams.h"
 #include "bool-proc.h"
+#include "snprintf.h"
 
 /*
 // returns the full, qualified pathname of the default htp include file
@@ -303,7 +304,7 @@ BOOL ReadHtmlMarkup(STREAM *infile, STREAM *outfile,
                 /* comment tag: check for -- */
                 ? strncmp(markupBuffer+ctr-3, "--", 2) == 0
                 /* PHP tag: check for ? */
-                : markupBuffer[1] == '?' ? markupBuffer[ctr-2] == '?'
+                : markupBuffer[0] == '?' ? markupBuffer[ctr-2] == '?'
                 /* normal tag: check for matching quotes */
                 : inQuotes == NUL)
             {
@@ -419,6 +420,7 @@ BOOL FullyCheckDependencies(const char *in, const char *out)
         /* check markup type ... only interested in htp markups currently */
         if((markupType & MARKUP_TYPE_HTP) == 0)
         {
+            DestroyMarkupStruct(&markup);
             continue;
         }
 
@@ -432,6 +434,7 @@ BOOL FullyCheckDependencies(const char *in, const char *out)
                 /* If we find an execute tag, we can't be sure that it
                  * is up to date */
                 result = FALSE;
+                DestroyMarkupStruct(&markup);
                 break;
             }
             includeFile = MarkupAttributeValue(&markup, "INCLUDE");
