@@ -426,7 +426,7 @@ BOOL ProcessResponseFile(VARSTORE *parentVarStore, const char *resp)
         while(ptr != NULL)
         {
             /* is this just a repeated token? */
-            if((*ptr == ' ') || (*ptr == '\t'))
+            if((*ptr == ' ') || (*ptr == '\t') || !(*ptr))
             {
                 ptr = StringNextToken(&findToken);
                 continue;
@@ -462,7 +462,10 @@ BOOL ProcessResponseFile(VARSTORE *parentVarStore, const char *resp)
             ptr = StringNextToken(&findToken);
         }
 
-        if(out == NULL)
+        if (in == NULL)
+            continue;
+
+        if (out == NULL)
         {
             char tempFilename[MAX_PATHNAME_LEN];
             StringCopy(tempFilename, projectFilename, MAX_PATHNAME_LEN);
@@ -470,7 +473,9 @@ BOOL ProcessResponseFile(VARSTORE *parentVarStore, const char *resp)
             /* in is the response file.
              * recurse but with the parentVarStore.
              */
+            PopVariableStoreContext(&projectVarStore);
             result = ProcessResponseFile(parentVarStore, in);
+            PushVariableStoreContext(parentVarStore, &projectVarStore);
 
             /* restore the projectFilename for dependency checking */
             StringCopy(projectFilename, tempFilename, MAX_PATHNAME_LEN);
