@@ -444,19 +444,7 @@ uint ExpandMetatag(TASK *task, HTML_MARKUP *htmlMarkup)
     InitializeVariableStore(&defVarstore);
 
     /* if NULL, then no options allowed */
-    if(options == NULL)
-    {
-        if(htmlMarkup->attrib != NULL)
-        {
-            HtpMsg(MSG_ERROR, task->infile,
-                   "DEF macro \"%s\" does not specify any options",
-                   defName);
-            DestroyVariableStore(&defVarstore);
-            return MARKUP_ERROR;
-        }
-    }
-    else
-    {
+    if (options != NULL) {
         /* options should be space-delimited, use StringToken() */
         if((optionCopy = DuplicateString(options)) == NULL)
         {
@@ -464,84 +452,74 @@ uint ExpandMetatag(TASK *task, HTML_MARKUP *htmlMarkup)
             DestroyVariableStore(&defVarstore);
             return MARKUP_ERROR;
         }
+        
+        hasWildcard = FALSE;
 
         /* build array of pointers to null-terminated option */
         optionPtr = StringFirstToken(&findToken, optionCopy, " ");
-        hasWildcard = FALSE;
         while (optionPtr != NULL)
         {
             /* ignore multiple spaces */
-            if (*optionPtr != NUL)
+            if (*optionPtr == NUL)
+                continue;
+            if (strcmp(optionPtr, "*") == 0)
             {
-
-                if (strcmp(optionPtr, "*") == 0)
-                {
-                    hasWildcard = TRUE;
+                hasWildcard = TRUE;
+            }
+            else if ((attrib = UnlinkAttributeInMarkup(htmlMarkup,
+                                                       optionPtr)) != NULL)
+            {
+                /* since this is a good attribute, add it to the
+                 * local store 
+                 */
+                
+                flag = VAR_FLAG_DEALLOC_NAME | VAR_FLAG_DEALLOC_VALUE;
+                value = attrib->value;
+                if (value == NULL) {
+                    value = "";
+                    flag &= ~VAR_FLAG_DEALLOC_VALUE;
                 }
-                else if ((attrib = UnlinkAttributeInMarkup(htmlMarkup,
-                                                           optionPtr)) != NULL)
+                
+                if(StoreVariable(&defVarstore, attrib->name, attrib->value,
+                                 VAR_TYPE_SET_MACRO, 
+                                 flag, NULL, NULL) == FALSE)
                 {
-                    /* since this is a good attribute, add it to the
-                     * local store 
-                     */
-                    
-                    flag = VAR_FLAG_DEALLOC_NAME | VAR_FLAG_DEALLOC_VALUE;
-                    value = attrib->value;
-                    if (value == NULL) {
-                        value = "";
-                        flag &= ~VAR_FLAG_DEALLOC_VALUE;
-                    }
-                    
-                    if(StoreVariable(&defVarstore, attrib->name, attrib->value,
-                                     VAR_TYPE_SET_MACRO, 
-                                     flag, NULL, NULL) == FALSE)
-                    {
-                        HtpMsg(MSG_ERROR, task->infile,
-                               "Unable to store local macro for metatag");
-                        DestroyVariableStore(&defVarstore);
-                        DestroyAttribute(attrib);
-                        FreeMemory(attrib);
-                        FreeMemory(optionCopy);
-                        return MARKUP_ERROR;
-                    }
-                    if (attrib->whitespace)
-                        FreeMemory(attrib->whitespace);
+                    HtpMsg(MSG_ERROR, task->infile,
+                           "Unable to store local macro for metatag");
+                    DestroyVariableStore(&defVarstore);
+                    DestroyAttribute(attrib);
                     FreeMemory(attrib);
+                    FreeMemory(optionCopy);
+                    return MARKUP_ERROR;
                 }
-                else
-                {
-                    char *name = DuplicateString(optionPtr);
-                    /* This option is undefined.  Add an explicit
-                     * undefined value to hide variables with same
-                     * name in outer scope.
-                     */
-                    if (StoreVariable(&defVarstore, name, NULL,
-                                      VAR_TYPE_UNKNOWN, 
-                                      VAR_FLAG_DEALLOC_NAME
-                                      | VAR_FLAG_UNDEFINED,
-                                      NULL, NULL) == FALSE) {
-                        HtpMsg(MSG_ERROR, task->infile,
-                               "Unable to store local macro for metatag");
-                        DestroyVariableStore(&defVarstore);
-                        FreeMemory(name);
-                        FreeMemory(optionCopy);
-                        return MARKUP_ERROR;
-                    }
+                if (attrib->whitespace)
+                FreeMemory(attrib->whitespace);
+                FreeMemory(attrib);
+            }
+            else
+            {
+                char *name = DuplicateString(optionPtr);
+                /* This option is undefined.  Add an explicit
+                 * undefined value to hide variables with same
+                 * name in outer scope.
+                 */
+                if (StoreVariable(&defVarstore, name, NULL,
+                                  VAR_TYPE_UNKNOWN, 
+                                  VAR_FLAG_DEALLOC_NAME
+                                  | VAR_FLAG_UNDEFINED,
+                                  NULL, NULL) == FALSE) {
+                    HtpMsg(MSG_ERROR, task->infile,
+                           "Unable to store local macro for metatag");
+                    DestroyVariableStore(&defVarstore);
+                    FreeMemory(name);
+                    FreeMemory(optionCopy);
+                    return MARKUP_ERROR;
                 }
             }
             optionPtr = StringNextToken(&findToken);
         }
         FreeMemory(optionCopy);
-
-        if (!hasWildcard && htmlMarkup->attrib != NULL
-            && macroType == VAR_TYPE_DEF_MACRO) {
-            HtpMsg(MSG_ERROR, task->infile,
-                   "DEF macro \"%s\" does not accept a parameter named \"%s\"",
-                   defName, htmlMarkup->attrib->name);
-            DestroyVariableStore(&defVarstore);
-            return MARKUP_ERROR;
-        }
-        
+    
         if (hasWildcard)
         {
             uint wildcardLength = 0;
@@ -626,19 +604,29 @@ uint ExpandMetatag(TASK *task, HTML_MARKUP *htmlMarkup)
         }
     }
 
+    if (htmlMarkup->attrib != NULL) {
+        HtpMsg(MSG_ERROR, task->infile,
+               "%s metatag \"%s\" does not accept a parameter named \"%s\"",
+               macroType == VAR_TYPE_BLOCKDEF_MACRO ? "blockdef" : "def",
+               defName, htmlMarkup->attrib->name);
+        DestroyVariableStore(&defVarstore);
+        return MARKUP_ERROR;
+    }
+    
     /* expand the DEF macro like a block macro ... */
 
     /* open the file the macro is held in */
     if(CreateBufferReader(&defFile, defStream) == FALSE)
     {
         HtpMsg(MSG_ERROR, task->infile,
-            "unable to open block for DEF macro \"%s\"",
-            defName);
+               "unable to open block for %s metatag \"%s\"",
+               macroType == VAR_TYPE_BLOCKDEF_MACRO ? "blockdef" : "def",
+               defName);
         DestroyVariableStore(&defVarstore);
         return MARKUP_ERROR;
     }
 
-    HtpMsg(MSG_INFO, task->infile, "dereferencing %s macro \"%s\"", 
+    HtpMsg(MSG_INFO, task->infile, "dereferencing %s metatag \"%s\"", 
            macroType == VAR_TYPE_BLOCKDEF_MACRO ? "blockdef" : "def",
            defName);
 
