@@ -16,7 +16,7 @@
 
 #include "defs.h"
 
-uint CommentProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext);
+uint HeadProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext);
 uint QuoteProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext);
 
 uint HtpCommentProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext);
