@@ -12,6 +12,7 @@
 
 #include "htp.h"
 #include "option.h"
+#include "snprintf.h"
 
 /* symbols used to express severity of message */
 const char *severitySymbol[3] =
@@ -117,7 +118,7 @@ void DebugMsg(const char *format, ...)
     va_end(argptr);
 
     /* write the string to disk */
-    fprintf(debugMsgFile, str);
+    fprintf(debugMsgFile, "%s", str);
 
     /* flush it out to disk */
     fflush(debugMsgFile);
