@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
 //
-// $Id: streams.c,v 1.13 2002/11/14 14:38:06 hoenicke Exp $
+// $Id: streams.c,v 1.14 2006/06/12 13:41:33 hoenicke Exp $
 //
 // file/buffer stream functions
 //
@@ -281,15 +281,16 @@ BOOL StreamPrintF(STREAM *stream, const char *format, ...)
 
     /* convert formatted arguments into single string */
     va_start(argptr, format);
-
     len = vsnprintf(str, sizeof(buffer), format, argptr);
+    va_end(argptr);
+
     if (len > sizeof(buffer) - 1) {
         str = AllocMemory(len + 1);
+        va_start(argptr, format);
         len = vsnprintf(str, len + 1, format, argptr);
+        va_end(argptr);
     }
 
-    va_end(argptr);
-
     len = PutStreamString(stream, str);
 
     if (str != buffer)
