@@ -20,7 +20,7 @@ void DisplayHeader(void)
 {
     printf("\n%s %s - HTML pre-processor\n", PROGRAM_NAME, VER_STRING);
     printf("Copyright (c) 1995-96 Jim Nelson\n");
-    printf("Copyright (c) 2002 Jochen Hoenicke, Michael Mller under Artistic License\n");
+    printf("Copyright (c) 2002-03 Jochen Hoenicke under Artistic License\n");
     printf("[%s]\n\n", PROGRAM_OS);
 }   
 
@@ -33,7 +33,7 @@ void usage(void)
         PROGRAM_NAME);
     printf("       %s [options] @<response file>\n", PROGRAM_NAME);
     printf("       %s [options] @\n", PROGRAM_NAME);
-    printf("\nSee accompanying readme.txt and on-line reference for full details.\n");
+    printf("\nSee on-line reference for full details.\n");
     printf("\nThis is software is released unter the Artistic License.\n");
 }   
 
